pub struct ConstructorOptions {Show 23 fields
pub nargs: Option<usize>,
pub bounded: bool,
pub mode: Option<String>,
pub sizer: Option<SizingClosure>,
pub before_digest: Vec<BeforeDigestClosure>,
pub after_digest: Vec<DigestionClosure>,
pub before_construct: Vec<ConstructionClosure>,
pub after_construct: Vec<ConstructionClosure>,
pub enter_horizontal: bool,
pub leave_horizontal: bool,
pub require_math: bool,
pub forbid_math: bool,
pub properties: PropertiesClosure,
pub capture_body: bool,
pub font: Option<FontDirective>,
pub after_digest_begin: Vec<DigestionClosure>,
pub before_digest_end: Vec<BeforeDigestClosure>,
pub after_digest_body: Vec<DigestionClosure>,
pub reversion: Option<Reversion>,
pub scope: Option<Scope>,
pub robust: bool,
pub locked: bool,
pub alias: Option<String>,
}Expand description
configuration for creating a new Constructor
Fields
nargs: Option<usize>number of arguments (if any)
bounded: boolbouded mode (default: false)
mode: Option<String>begin a named mode
sizer: Option<SizingClosure>a SizingClosure to estimate the size of the digested box
before_digest: Vec<BeforeDigestClosure>custom code to run immediately before the digestion phase
after_digest: Vec<DigestionClosure>custom code to run immediately after the digestion phase
before_construct: Vec<ConstructionClosure>custom code to run immediately before the construction phase
after_construct: Vec<ConstructionClosure>custom code to run immediately after the construction phase
enter_horizontal: boolswitch to horizontal mode before digesting (Perl: enterHorizontal => 1)
leave_horizontal: boolswitch to vertical mode before digesting (Perl: leaveHorizontal => 1)
require_math: boolrequires to be used in math mode
forbid_math: boolforbids use in math mode
properties: PropertiesClosurecustom directives for computing box properties
capture_body: boolshould it capture the body as #body (default: false)
font: Option<FontDirective>specify a font to use, or instructions how to compute which font to use
after_digest_begin: Vec<DigestionClosure>custom code to run as digestion begins
before_digest_end: Vec<BeforeDigestClosure>custom code to run just before digestion ends
after_digest_body: Vec<DigestionClosure>custom code to run after #body has been digested
reversion: Option<Reversion>provide tokens to revert to, or custom code for computing them
scope: Option<Scope>Local/Global scope of installing this definition (default: Local)
robust: boolis this a robust command sequence (default: false)
locked: boollock the definition for raw TeX overrides (default: false)
alias: Option<String>alternative (command sequence) name, used for reversion